@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Tk::Cards;
 BEGIN {
-  $Games::Risk::Tk::Cards::VERSION = '3.101511';
+  $Games::Risk::Tk::Cards::VERSION = '3.101590';
 }
 # ABSTRACT: cards listing
 
@@ -82,9 +82,6 @@ sub START {
     my ($self, $s) = @_[OBJECT, SESSION];
     $K->alias_set('cards');
 
-    #--
-    $self->_w('ok')->configure(disabled);
-
     #-- trap some events
     my $top = $self->_toplevel;
     $top->protocol( WM_DELETE_WINDOW => $s->postback('visibility_toggle'));
@@ -353,6 +350,20 @@ sub _build_gui {
 }
 
 
+#
+# $self->_finish_gui;
+#
+# called by tk:role:dialog to finish the inner dialog building.
+# needed because win32 somehow mixes START with BUILD. very strange...
+#
+sub _finish_gui {
+    my $self = shift;
+
+    # prevent validation button to be clicked.
+    $self->_w('ok')->configure(disabled);
+}
+
+
 #
 # $self->_valid;
 #
@@ -380,7 +391,7 @@ Games::Risk::Tk::Cards - cards listing
 
 =head1 VERSION
 
-version 3.101511
+version 3.101590
 
 =head1 DESCRIPTION
 
